**To describe reserved DB instances**

The following ``describe-reserved-db-instances`` example retrieves details about any reserved DB instances in the current AWS account. ::

    aws rds describe-reserved-db-instances

